# Changelog

<!--next-version-placeholder-->

## v1.3.0 (2021-10-22)
### Feature
* Add language support ([`4650dda`](https://github.com/eifinger/aiohere/commit/4650ddab423f5f3b27ea6e354e3d0aef4169cdcd))

## v1.2.0 (2021-09-10)
### Feature
* Expose Errors in API ([`6b2f755`](https://github.com/eifinger/aiohere/commit/6b2f75561262aecb007e9916b728bc66456171c1))

## v1.1.0 (2021-09-10)
### Feature
* Noop release ([`f535a9e`](https://github.com/eifinger/aiohere/commit/f535a9e467241157f521dded3a4db2f045dc9b1b))

## v1.0.1 (2021-09-10)
### Fix
* Correct version var ([`9524dc3`](https://github.com/eifinger/aiohere/commit/9524dc308dacfb8b5f1bb7d79a8d29b9e501d084))
